
import os, sys, datetime



class AllParameters():

	ParameterFileName = 'config.dat'
	MainPath = os.getcwd()
	CachePath = os.path.join(MainPath, 'cache')

	ParameterDescriptionValue = [\
		'Start Time', '2010-01-01',\
		'End Time', datetime.datetime.strftime(datetime.datetime.now(), '%Y-%m-%d %H:%M:%S').split(' ')[0],\
		'Min EQ Magnitude', 7.5,\
		'Max EQ Depth (km)', 50,\
		'Update DART Stations List','no',\
		'Auto Choose n DART Stations (n nearest; -1 manual)', 5,\
		'Manually Chosen DART Stations', [],\
		'Update IOC Stations List','no',\
		'Auto Choose n IOC Stations  (n nearest; -1 manual)', 5,\
		'Manually Chosen IOC Stations', [],\
		'Use (1/Filter) or (2/Polynomial) to Remove Tides', 2,\
		'Filter Maximum Period (min)', 120,\
		'Polynomial Order', 40,\
		'Tsunami Data Lasting Time (min)', 200]

	MaxLen = 0 # string length of config file

	nDataLengthDay = 1 # download data for plus minus nDatalengthDay day



	def __init__(self):

		maxlen = 0
		for i in range(0,len(self.ParameterDescriptionValue)-1,2):
			maxlen = max(maxlen, len(self.ParameterDescriptionValue[i]))
		self.MaxLen = maxlen

		if(os.path.exists(self.CachePath) == False):
			os.mkdir(self.CachePath)
		self.clearCache()
	


	def clearCache(self):

		for f in os.listdir(self.CachePath):
			if(os.path.isfile(os.path.join(self.CachePath, f)) == True):
				if(f != 'earthquake_usgs.csv'):
					os.remove(os.path.join(self.CachePath, f))



	def readParameters(self):

		if(os.path.isfile('config.dat') == True):
			print('\n--> Read parameters from file '+self.ParameterFileName+' ...\n')
			self.readParametersFromFile()
		else:
			print('\n--> Use and Save default parameters (file '+self.ParameterFileName+' not found) ...\n')
			self.saveParameters(True)
		self.syncParameters()



	def readParametersFromFile(self):

		f = open(self.ParameterFileName, 'r')
		s = f.read().strip()
		f.close()

		l = s.splitlines()
		cl = [x.split(':')[1].strip() for x in l]

		n = 0
		self.ParameterDescriptionValue[2*n+1] = cl[n]; n += 1
		self.ParameterDescriptionValue[2*n+1] = cl[n]; n += 1
		self.ParameterDescriptionValue[2*n+1] = float(cl[n]); n += 1
		self.ParameterDescriptionValue[2*n+1] = float(cl[n]); n += 1
		self.ParameterDescriptionValue[2*n+1] = cl[n].lower(); n += 1
		self.ParameterDescriptionValue[2*n+1] = int(cl[n]); n += 1
		if(cl[n] == ''):
			self.ParameterDescriptionValue[2*n+1] = []; n += 1
		else:
			self.ParameterDescriptionValue[2*n+1] = [x.strip() for x in cl[n].split(',')]; n += 1
		self.ParameterDescriptionValue[2*n+1] = cl[n].lower(); n += 1
		self.ParameterDescriptionValue[2*n+1] = int(cl[n]); n += 1
		if(cl[n] == ''):
			self.ParameterDescriptionValue[2*n+1] = []; n += 1
		else:
			self.ParameterDescriptionValue[2*n+1] = [x.strip() for x in cl[n].split(',')]; n += 1
		self.ParameterDescriptionValue[2*n+1] = int(cl[n]); n += 1
		self.ParameterDescriptionValue[2*n+1] = float(cl[n]); n += 1
		self.ParameterDescriptionValue[2*n+1] = int(cl[n]); n += 1
		self.ParameterDescriptionValue[2*n+1] = float(cl[n]); n += 1
		


	def printParameters(self):

		for i in range(0,len(self.ParameterDescriptionValue)-1,2):
			print(' '*4+self.ParameterDescriptionValue[i].ljust(self.MaxLen+4,' ')+':  ',
				self.ParameterDescriptionValue[i+1])



	def saveParameters(self, DefaultParameters):
		
		f = open(self.ParameterFileName, 'w')
		for i in range(0,len(self.ParameterDescriptionValue)-1,2):
			s = self.ParameterDescriptionValue[i].ljust(self.MaxLen+4,' ')+':  '
			if(type(self.ParameterDescriptionValue[i+1]) is list):
				s += ','.join(self.ParameterDescriptionValue[i+1])
			elif(DefaultParameters == True and i == 2):
				s += 'now'
			else:
				s += str(self.ParameterDescriptionValue[i+1])
			f.write(s+'\n')
		f.close()
	


	def syncParameters(self):

		[self.StartTime, self.EndTime, self.MinMagnitude, self.MaxDepth, self.UpdateDARTStations, self.AutoChooseDARTStations,\
		 self.DARTStationsList, self.UpdateIOCStations, self.AutoChooseIOCStations, self.IOCStationsList,\
		 self.FilterOrPolynomial, self.FilterMaxPeriod, self.PolynomialOrder, self.TsunamiDataLength] \
		 = self.ParameterDescriptionValue[1:len(self.ParameterDescriptionValue):2]
		if(self.EndTime.strip().lower() == 'now'):
			self.EndTime = datetime.datetime.strftime(datetime.datetime.now(), '%Y-%m-%d %H:%M:%S').split(' ')[0]
