#! /opt/local/bin/python3.8
## version 2.0, last update: 2022/1/15 ##

import os, platform

ThisOS = platform.system()
if(ThisOS == 'Windows'): # WINDOWS
	os.environ['PROJ_LIB'] = r'C:\ProgramData\Miniconda3\pkgs\proj-7.2.0-h3e70539_0\Library\share\proj'


from AllParameters import AllParameters
from WebpageDownloader import WebpageDownloader
from USGSEarthquakeInfo import USGSEarthquakeInfo
from TsunamiData import TsunamiData
from FunctionsLib import generateHTMLViewer



###################### set up parameters ######################
AllParams = AllParameters()
AllParams.readParameters()
AllParams.printParameters()
command = input('\nPress Enter or input Yes/yes/Y/y to continue; other to exit ... ')
if(command != 'Yes' and command != 'yes' and command != 'Y' and command != 'y' and command.strip() != ''):
	exit(0)
#print(vars(AllParams))
wpd = WebpageDownloader()



###################### USGS earthquake class  ######################
print('\n--> Download USGS earthquake catalog ...')
usgs = USGSEarthquakeInfo(AllParams.CachePath)
#usgs.getUSGSEarthquakes(AllParams, wpd)
usgs.printUSGSEarthquakes()
usgs.selectUSGSEarthquake()
if(usgs.EQID < 0):
	exit(0)



###################### DART data ######################
dart = TsunamiData(AllParams.CachePath, 'DART')
if(AllParams.UpdateDARTStations == 'yes' or len(dart.AllStationsNames) == 0):
	print('\n--> Update DART stations ...')
	dart.updateStations(wpd)
print('\n--> Select and download DART data ...')
dart.chooseStations(AllParams, usgs)
dart.downloadData(AllParams, usgs, wpd)
print('\n--> Process DART data and make plots ...')
dart.removeTidesAllStations(AllParams)
dart.makePlotsAllStations(AllParams)



###################### IOC data ######################
ioc = TsunamiData(AllParams.CachePath, 'IOC')
if(AllParams.UpdateIOCStations == 'yes' or len(ioc.AllStationsNames) == 0):
	print('\n--> Update IOC stations ...')
	ioc.updateStations(wpd)
print('\n--> Select and download IOC data ...')
ioc.chooseStations(AllParams, usgs)
ioc.downloadData(AllParams, usgs, wpd)
print('\n--> Process IOC data and make plots ...')
ioc.removeTidesAllStations(AllParams)
ioc.makePlotsAllStations(AllParams)



###################### Generate HTML Viewer ######################
print('\n--> Generate HTML image viewer ...')
generateHTMLViewer(AllParams, usgs, dart, ioc)

if(ThisOS == 'Darwin'): # MAC
	os.system('open MainMap.html')
elif(ThisOS == 'Windows'): # WINDOWS
	os.startfile('MainMap.html')
elif(ThisOS == 'Linux'):
	os.system('gio open MainMap.html')

print('\n--> END.\n')

